<?php
/**
 * Generate post meta fields for ACF
 *
 * @package     Schema
 * @subpackage  Schema Post Meta ACF
 * @copyright   Copyright (c) 2017, Hesham Zebida
 * @license     http://opensource.org/licenses/gpl-2.0.php GNU Public License
 * @since       1.0.0
 */


// Exit if accessed directly
if ( ! defined( 'ABSPATH' ) ) exit;

function schema_wp_types_acf_address_fields( $key = '', $name = '', $type = 'address', $label = '', $instructions = '' ) {
	
	$fields = array( 
	
			'key' => $key,
			'label' => $label,
			'name' => $name,
			'type' => 'group',
			'instructions' => $instructions,
			'required' => 0,
			'conditional_logic' => 0,
			'wrapper' => array (
				'width' => '',
				'class' => '',
				'id' => '',
			),
			'layout' => 'block',
			'sub_fields' => array (
				array (
					'key' => $key . '_streetAddress',
					'label' => __('Street address', 'schema-wp-types'),
					'name' => 'streetAddress',
					'type' => 'text',
					'instructions' => '',
					'required' => 0,
					'conditional_logic' => 0,
					'wrapper' => array (
						'width' => '33.3',
						'class' => '',
						'id' => '',
					),
					'default_value' => '',
					'placeholder' => '',
					'prepend' => '',
					'append' => '',
					'maxlength' => '',
				),
				array (
					'key' => $key . '_streetAddress_2',
					'label' => __('Street address 2', 'schema-wp-types'),
					'name' => 'streetAddress_2',
					'type' => 'text',
					'instructions' => '',
					'required' => 0,
					'conditional_logic' => 0,
					'wrapper' => array (
						'width' => '33.3',
						'class' => '',
						'id' => '',
					),
					'default_value' => '',
					'placeholder' => '',
					'prepend' => '',
					'append' => '',
					'maxlength' => '',
				),
				array (
					'key' => $key . '_streetAddress_3',
					'label' => __('Street address 3', 'schema-wp-types'),
					'name' => 'streetAddress_3',
					'type' => 'text',
					'instructions' => '',
					'required' => 0,
					'conditional_logic' => 0,
					'wrapper' => array (
						'width' => '33.3',
						'class' => '',
						'id' => '',
					),
					'default_value' => '',
					'placeholder' => '',
					'prepend' => '',
					'append' => '',
					'maxlength' => '',
				),
				array (
					'key' => $key . '_addressLocality',
					'label' => 'City',
					'name' => 'addressLocality',
					'type' => 'text',
					'instructions' => '',
					'required' => 0,
					'conditional_logic' => 0,
					'wrapper' => array (
						'width' => '25',
						'class' => '',
						'id' => '',
					),
					'default_value' => '',
					'placeholder' => '',
					'prepend' => '',
					'append' => '',
					'maxlength' => '',
				),
				array (
					'key' => $key . '_postalCode',
					'label' => 'Zip / Postal Code',
					'name' => 'postalCode',
					'type' => 'text',
					'instructions' => '',
					'required' => 0,
					'conditional_logic' => 0,
					'wrapper' => array (
						'width' => '25',
						'class' => '',
						'id' => '',
					),
					'default_value' => '',
					'placeholder' => '',
					'prepend' => '',
					'append' => '',
					'maxlength' => 5,
				),
				array (
					'key' => $key . '_addressRegion',
					'label' => 'State or Province',
					'name' => 'addressRegion',
					'type' => 'text',
					'instructions' => '',
					'required' => 0,
					'conditional_logic' => 0,
					'wrapper' => array (
						'width' => '25',
						'class' => '',
						'id' => '',
					),
					'default_value' => '',
					'placeholder' => '',
					'prepend' => '',
					'append' => '',
					'maxlength' => '',
				),
				array (
					'key' => $key . '_addressCountry',
					'label' => 'Country',
					'name' => 'addressCountry',
					'type' => 'select',
					'instructions' => '',
					'required' => 0,
					'conditional_logic' => 0,
					'wrapper' => array (
						'width' => '25',
						'class' => '',
						'id' => '',
					),
					'choices' => array (
						'afghanistan' => 'Afghanistan',
						'albania' => 'Albania',
						'algeria' => 'Algeria',
						'american_samoa' => 'American Samoa',
						'andorra' => 'Andorra',
						'angola' => 'Angola',
						'anguilla' => 'Anguilla',
						'antigua_and_barbuda' => 'Antigua and Barbuda',
						'argentina' => 'Argentina',
						'armenia' => 'Armenia',
						'aruba' => 'Aruba',
						'australia' => 'Australia',
						'austria' => 'Austria',
						'azerbaijan' => 'Azerbaijan',
						'bahamas' => 'Bahamas',
						'bahrain' => 'Bahrain',
						'bangladesh' => 'Bangladesh',
						'barbados' => 'Barbados',
						'belarus' => 'Belarus',
						'belgium' => 'Belgium',
						'belize' => 'Belize',
						'benin' => 'Benin',
						'bermuda' => 'Bermuda',
						'bhutan' => 'Bhutan',
						'bolivia' => 'Bolivia',
						'bosnia-herzegovina' => 'Bosnia-Herzegovina',
						'botswana' => 'Botswana',
						'bouvet_island' => 'Bouvet Island',
						'brazil' => 'Brazil',
						'brunei' => 'Brunei',
						'bulgaria' => 'Bulgaria',
						'burkina_faso' => 'Burkina Faso',
						'burundi' => 'Burundi',
						'cambodia' => 'Cambodia',
						'cameroon' => 'Cameroon',
						'canada' => 'Canada',
						'cape_verde' => 'Cape Verde',
						'cayman_islands' => 'Cayman Islands',
						'central_african_republic' => 'Central African Republic',
						'chad' => 'Chad',
						'chile' => 'Chile',
						'china' => 'China',
						'christmas_island' => 'Christmas Island',
						'cocos_(keeling)_islands' => 'Cocos (Keeling) Islands',
						'colombia' => 'Colombia',
						'comoros' => 'Comoros',
						'congo,_democratic_republic_of_the_(zaire)' => 'Congo, Democratic Republic of the (Zaire)',
						'congo,_republic_of' => 'Congo, Republic of',
						'cook_islands' => 'Cook Islands',
						'costa_rica' => 'Costa Rica',
						'croatia' => 'Croatia',
						'cuba' => 'Cuba',
						'cyprus' => 'Cyprus',
						'czech_republic' => 'Czech Republic',
						'denmark' => 'Denmark',
						'djibouti' => 'Djibouti',
						'dominica' => 'Dominica',
						'dominican_republic' => 'Dominican Republic',
						'ecuador' => 'Ecuador',
						'egypt' => 'Egypt',
						'el_salvador' => 'El Salvador',
						'equatorial_guinea' => 'Equatorial Guinea',
						'eritrea' => 'Eritrea',
						'estonia' => 'Estonia',
						'ethiopia' => 'Ethiopia',
						'falkland_islands' => 'Falkland Islands',
						'faroe_islands' => 'Faroe Islands',
						'fiji' => 'Fiji',
						'finland' => 'Finland',
						'france' => 'France',
						'french_guiana' => 'French Guiana',
						'gabon' => 'Gabon',
						'gambia' => 'Gambia',
						'georgia' => 'Georgia',
						'germany' => 'Germany',
						'ghana' => 'Ghana',
						'gibraltar' => 'Gibraltar',
						'greece' => 'Greece',
						'greenland' => 'Greenland',
						'grenada' => 'Grenada',
						'guadeloupe_(french)' => 'Guadeloupe (French)',
						'guam_(usa)' => 'Guam (USA)',
						'guatemala' => 'Guatemala',
						'guinea' => 'Guinea',
						'guinea_bissau' => 'Guinea Bissau',
						'guyana' => 'Guyana',
						'haiti' => 'Haiti',
						'holy_see' => 'Holy See',
						'honduras' => 'Honduras',
						'hong_kong' => 'Hong Kong',
						'hungary' => 'Hungary',
						'iceland' => 'Iceland',
						'india' => 'India',
						'indonesia' => 'Indonesia',
						'iran' => 'Iran',
						'iraq' => 'Iraq',
						'ireland' => 'Ireland',
						'israel' => 'Israel',
						'italy' => 'Italy',
						'ivory_coast_(cote_d`ivoire)' => 'Ivory Coast (Cote D`Ivoire)',
						'jamaica' => 'Jamaica',
						'japan' => 'Japan',
						'jordan' => 'Jordan',
						'kazakhstan' => 'Kazakhstan',
						'kenya' => 'Kenya',
						'kiribati' => 'Kiribati',
						'kuwait' => 'Kuwait',
						'kyrgyzstan' => 'Kyrgyzstan',
						'laos' => 'Laos',
						'latvia' => 'Latvia',
						'lebanon' => 'Lebanon',
						'lesotho' => 'Lesotho',
						'liberia' => 'Liberia',
						'libya' => 'Libya',
						'liechtenstein' => 'Liechtenstein',
						'lithuania' => 'Lithuania',
						'luxembourg' => 'Luxembourg',
						'macau' => 'Macau',
						'macedonia' => 'Macedonia',
						'madagascar' => 'Madagascar',
						'malawi' => 'Malawi',
						'malaysia' => 'Malaysia',
						'maldives' => 'Maldives',
						'mali' => 'Mali',
						'malta' => 'Malta',
						'marshall_islands' => 'Marshall Islands',
						'martinique_(french)' => 'Martinique (French)',
						'mauritania' => 'Mauritania',
						'mauritius' => 'Mauritius',
						'mayotte' => 'Mayotte',
						'mexico' => 'Mexico',
						'micronesia' => 'Micronesia',
						'moldova' => 'Moldova',
						'monaco' => 'Monaco',
						'mongolia' => 'Mongolia',
						'montenegro' => 'Montenegro',
						'montserrat' => 'Montserrat',
						'morocco' => 'Morocco',
						'mozambique' => 'Mozambique',
						'myanmar' => 'Myanmar',
						'namibia' => 'Namibia',
						'nauru' => 'Nauru',
						'nepal' => 'Nepal',
						'netherlands' => 'Netherlands',
						'netherlands_antilles' => 'Netherlands Antilles',
						'new_caledonia_(french)' => 'New Caledonia (French)',
						'new_zealand' => 'New Zealand',
						'nicaragua' => 'Nicaragua',
						'niger' => 'Niger',
						'nigeria' => 'Nigeria',
						'niue' => 'Niue',
						'norfolk_island' => 'Norfolk Island',
						'north_korea' => 'North Korea',
						'northern_mariana_islands' => 'Northern Mariana Islands',
						'norway' => 'Norway',
						'oman' => 'Oman',
						'pakistan' => 'Pakistan',
						'palau' => 'Palau',
						'panama' => 'Panama',
						'papua_new_guinea' => 'Papua New Guinea',
						'paraguay' => 'Paraguay',
						'peru' => 'Peru',
						'philippines' => 'Philippines',
						'pitcairn_island' => 'Pitcairn Island',
						'poland' => 'Poland',
						'polynesia_(french)' => 'Polynesia (French)',
						'portugal' => 'Portugal',
						'puerto_rico' => 'Puerto Rico',
						'qatar' => 'Qatar',
						'reunion' => 'Reunion',
						'romania' => 'Romania',
						'russia' => 'Russia',
						'rwanda' => 'Rwanda',
						'saint_helena' => 'Saint Helena',
						'saint_kitts_and_nevis' => 'Saint Kitts and Nevis',
						'saint_lucia' => 'Saint Lucia',
						'saint_pierre_and_miquelon' => 'Saint Pierre and Miquelon',
						'saint_vincent_and_grenadines' => 'Saint Vincent and Grenadines',
						'samoa' => 'Samoa',
						'san_marino' => 'San Marino',
						'sao_tome_and_principe' => 'Sao Tome and Principe',
						'saudi_arabia' => 'Saudi Arabia',
						'senegal' => 'Senegal',
						'serbia' => 'Serbia',
						'seychelles' => 'Seychelles',
						'sierra_leone' => 'Sierra Leone',
						'singapore' => 'Singapore',
						'slovakia' => 'Slovakia',
						'slovenia' => 'Slovenia',
						'solomon_islands' => 'Solomon Islands',
						'somalia' => 'Somalia',
						'south_africa' => 'South Africa',
						'south_georgia_and_south_sandwich_islands' => 'South Georgia and South Sandwich Islands',
						'south_korea' => 'South Korea',
						'south_sudan' => 'South Sudan',
						'spain' => 'Spain',
						'sri_lanka' => 'Sri Lanka',
						'sudan' => 'Sudan',
						'suriname' => 'Suriname',
						'svalbard_and_jan_mayen_islands' => 'Svalbard and Jan Mayen Islands',
						'swaziland' => 'Swaziland',
						'sweden' => 'Sweden',
						'switzerland' => 'Switzerland',
						'syria' => 'Syria',
						'taiwan' => 'Taiwan',
						'tajikistan' => 'Tajikistan',
						'tanzania' => 'Tanzania',
						'thailand' => 'Thailand',
						'timor-leste_(east_timor)' => 'Timor-Leste (East Timor)',
						'togo' => 'Togo',
						'tokelau' => 'Tokelau',
						'tonga' => 'Tonga',
						'trinidad_and_tobago' => 'Trinidad and Tobago',
						'tunisia' => 'Tunisia',
						'turkey' => 'Turkey',
						'turkmenistan' => 'Turkmenistan',
						'turks_and_caicos_islands' => 'Turks and Caicos Islands',
						'tuvalu' => 'Tuvalu',
						'uganda' => 'Uganda',
						'ukraine' => 'Ukraine',
						'united_arab_emirates' => 'United Arab Emirates',
						'united_kingdom' => 'United Kingdom',
						'united_states' => 'United States',
						'uruguay' => 'Uruguay',
						'uzbekistan' => 'Uzbekistan',
						'vanuatu' => 'Vanuatu',
						'venezuela' => 'Venezuela',
						'vietnam' => 'Vietnam',
						'virgin_islands' => 'Virgin Islands',
						'wallis_and_futuna_islands' => 'Wallis and Futuna Islands',
						'yemen' => 'Yemen',
						'zambia' => 'Zambia',
						'zimbabwe' => 'Zimbabwe',
					),
					'default_value' => array (
					),
					'allow_null' => 1,
					'multiple' => 0,
					'ui' => 0,
					'ajax' => 0,
					'return_format' => 'value',
					'placeholder' => '',
				),
			),
	);
	
	return $fields;
}
