<?php
/**
 * Schema Location Rules
 *
 * @package     Schema
 * @subpackage  Schema Post Meta
 * @copyright   Copyright (c) 2018, Hesham Zebida
 * @license     http://opensource.org/licenses/gpl-2.0.php GNU Public License
 * @since       1.0.0
 */

// Exit if accessed directly
if ( ! defined( 'ABSPATH' ) ) exit;


add_action( 'acf/init', 'schema_wp_types_acf_field_locations_group' );
/**
 * Create ACF field type Group for locations rules
 *
 * @since 1.0.0
 */
function schema_wp_types_acf_field_locations_group() {
	
	if( function_exists('acf_add_local_field_group') ):
		
		// ACF Group: Locations
		//
		//
		acf_add_local_field_group(array (
			'key' => 'schema_locations_group',
			'title' => __('Locations', 'schema-premium'),
			'location' => array (
				array (
					array (	 // custom locations
						'param' => 'post_type',
						'operator' => '==',
						'value' => 'schema',
					),
				),
			),
			'menu_order' => 10,
			'position' => 'normal',
			'style' => 'default',
			'label_placement' => 'left',
			'instruction_placement' => 'label',
			'hide_on_screen' => '',
			'active' => 1,
			'description' => '',
		));
	
	endif;
}

add_action( 'acf/init', 'schema_wp_types_acf_field_locations_enable_rules' );
/**
 * Create ACF repeater field for
 *
 * Locations Rules field: Enable Rules
 *
 * @since 1.0.0
 */
function schema_wp_types_acf_field_locations_enable_rules() {
	
	if( function_exists('acf_add_local_field_group') ):
		
		// Repeater
		//
		//
		acf_add_local_field( apply_filters( 'field_schema_locations', array(
			'key' => 'field_schema_locations',
			'name' => 'schema_locations',
			'label' => __('Enable Rules', 'schema-premium'),
			'instructions'	=> __('Create a set of rules to determine the target of this schema.org type', 'schema-premium'), 
			'type' => 'repeater',
			'parent' => 'schema_locations_group',
			'collapsed' => '',
			'min' => 1,
			'max' => 0,
			'layout' => 'table',
			'button_label' => __('Add Enable Rule', 'schema-premium'),
		) ) );
		
		// Sub Repeater Group
		//
		//
		acf_add_local_field(array(
			'key' 		=> 'group_schema_locations_sub',
			'label' 	=> __('Enable Schema markup on', 'schema-premium'),
			'name' 		=> 'locations_group_sub',
			'type' 		=> 'group',
			'layout' 	=> 'block',
			'parent' 	=> 'field_schema_locations',
			'required' => 1,
		));
		
		// Sub Repeater Field Select
		//
		//
		
		$locations_choices = schema_wp_get_locations_choices();
		
		acf_add_local_field(array(
			'key' 		=> 'field_schema_locations_select',
			'label' 	=> '',
			'name' 		=> 'schema_locations_select',
			'type' 		=> 'select',
			'instructions' => '',
			
			'conditional_logic' => 0,
			'wrapper' => array(
				'width' => '50',
			),
			'parent' 	=> 'group_schema_locations_sub',
			'choices' => $locations_choices,
			'default_value' => array(
			),
			'allow_null' => 0,
			'multiple' => 0,
			'ui' => 0,
			'ajax' => 0,
			'return_format' => 'value',
		));
		
		//
		//
		// Sub Repeater Fields 
		// With conditional logic based on selection
		//
		//
		
		// define array
		$feilds = schema_wp_get_locations_fields_options();
		
		// Create fields
		foreach ( $feilds as $key => $details) {
		
			acf_add_local_field(array(
				'key' 		=> $key . '_location',
				'label' 	=> '',
				'name' 		=> $key . '_location',
				'type' 		=> $details['type'],
				'instructions' => '',
				'required' => 0,
				'conditional_logic' => array(
									array(
										array(
											'field' => 'field_schema_locations_select',
											'operator' => '==',
											'value' => $details['value'],
										),
									),
								),
				'wrapper' => array(
					'width' => '50',
				),
				'parent' 	=> 'group_schema_locations_sub',
				'return_format' => 'value',
			));
		} // end foreach
		
		// Posts
		acf_add_local_field(array(
			'key' 		=> 'field_schema_post_location',
			'label' 	=> '',
			'name' 		=> 'schema_post_location',
			'type' 		=> 'post_object',
			'instructions' => '',
			'required' => 0,
			'conditional_logic' => array(
								array(
									array(
										'field' => 'field_schema_locations_select',
										'operator' => '==',
										'value' => 'post',
									),
								),
							),
			'wrapper' => array(
				'width' => '50',
			),
			'post_type' => array(
								0 => 'post',
							),
			'parent' 	=> 'group_schema_locations_sub',
			'return_format' => 'value',
		));
		
		// Pages
		acf_add_local_field(array(
			'key' 		=> 'field_schema_page_location',
			'label' 	=> '',
			'name' 		=> 'schema_page_location',
			'type' 		=> 'post_object',
			'instructions' => '',
			'required' => 0,
			'conditional_logic' => array(
								array(
									array(
										'field' => 'field_schema_locations_select',
										'operator' => '==',
										'value' => 'page',
									),
								),
							),
			'wrapper' => array(
				'width' => '50',
			),
			'post_type' => array(
								0 => 'page',
							),
			'parent' 	=> 'group_schema_locations_sub',
			'return_format' => 'value',
		));
		
 	endif;
}

add_action( 'acf/init', 'schema_wp_types_acf_field_locations_exclusion_rules' );
/**
 * Create ACF repeater field for
 *
 * Locations Rules field: Exclution Rules
 *
 * @since 1.0.0
 */
function schema_wp_types_acf_field_locations_exclusion_rules() {
	
	if( function_exists('acf_add_local_field_group') ):
		
		// Repeater
		//
		//
		acf_add_local_field( apply_filters( 'field_schema_exclution', array(
			'key' => 'field_schema_exclution',
			'name' => 'schema_exclution',
			'label' => __('Exclusion Rules', 'schema-premium'),
			'instructions'	=> '', 
			'type' => 'repeater',
			'parent' => 'schema_locations_group',
			'collapsed' => '',
			'min' => 0,
			'max' => 0,
			'layout' => 'table',
			'button_label' => __('Add Exclution Rule', 'schema-premium'),
		) ) );
		
		// Sub Repeater Group
		//
		//
		acf_add_local_field(array(
			'key' 		=> 'group_schema_exclution_sub',
			'label' 	=> __('Exclude schema markup on', 'schema-premium'),
			'name' 		=> 'exclusion_group_sub',
			'type' 		=> 'group',
			'layout' 	=> 'block',
			'parent' 	=> 'field_schema_exclution',
		));
		
		// Sub Repeater Field Select
		//
		//
		
		// define array
		$locations_choices = schema_wp_get_locations_choices();
		
		acf_add_local_field(array(
			'key' 		=> 'field_schema_exclusion_select',
			'label' 	=> '',
			'name' 		=> 'schema_exclution_select',
			'type' 		=> 'select',
			'instructions' => '',
			'required' => 0,
			'conditional_logic' => 0,
			'wrapper' => array(
				'width' => '50',
			),
			'parent' 	=> 'group_schema_exclution_sub',
			'choices' => $locations_choices,
			'default_value' => array(
			),
			'allow_null' => 0,
			'multiple' => 0,
			'ui' => 0,
			'ajax' => 0,
			'return_format' => 'value',
		));
		
		//
		//
		// Sub Repeater Fields 
		// With conditional logic based on selection
		//
		//
		
		// define array
		$feilds = schema_wp_get_locations_fields_options();
		
		// Create fields
		foreach ( $feilds as $key => $details) {
		
			acf_add_local_field(array(
				'key' 		=> $key . '_exclution',
				'label' 	=> '',
				'name' 		=> $key . '_exclution',
				'type' 		=> $details['type'],
				'instructions' => '',
				'required' => 0,
				'conditional_logic' => array(
									array(
										array(
											'field' => 'field_schema_exclusion_select',
											'operator' => '==',
											'value' => $details['value'],
										),
									),
								),
				'wrapper' => array(
					'width' => '50',
				),
				'parent' 	=> 'group_schema_exclution_sub',
				'return_format' => 'value',
			));
		} // end foreach
		
		// Posts
		acf_add_local_field(array(
			'key' 		=> 'field_schema_post_exclution',
			'label' 	=> '',
			'name' 		=> 'schema_post_exclution',
			'type' 		=> 'post_object',
			'instructions' => '',
			'required' => 0,
			'conditional_logic' => array(
								array(
									array(
										'field' => 'field_schema_exclusion_select',
										'operator' => '==',
										'value' => 'post',
									),
								),
							),
			'wrapper' => array(
				'width' => '50',
			),
			'post_type' => array(
								0 => 'post',
							),
			'parent' 	=> 'group_schema_exclution_sub',
			'return_format' => 'value',
		));
		
		// Pages
		acf_add_local_field(array(
			'key' 		=> 'field_schema_page_exclution',
			'label' 	=> '',
			'name' 		=> 'schema_page_exclution',
			'type' 		=> 'post_object',
			'instructions' => '',
			'required' => 0,
			'conditional_logic' => array(
								array(
									array(
										'field' => 'field_schema_exclusion_select',
										'operator' => '==',
										'value' => 'page',
									),
								),
							),
			'wrapper' => array(
				'width' => '50',
			),
			'post_type' => array(
								0 => 'page',
							),
			'parent' 	=> 'group_schema_exclution_sub',
			'return_format' => 'value',
		));
		
 	endif;
}

/**
 * Get locations options choices
 *
 * @since 1.0.0
 *
 * @return array
 */
function schema_wp_get_locations_choices() {
	
	$options = array ( 
		''	=> __('— Select —', 'schema-premium'), 
		'Everywhere' => array ( 
			'all_singulars'		=> __('All Singulars', 'schema-premium'), 
		),
		'Post' => array ( 
			'post_type' 		=> __('Post Type', 'schema-premium'), 
			'post_format' 		=> __('Post Format', 'schema-premium'),
			'post_status' 		=> __('Post Status', 'schema-premium'),
			'post_category' 	=> __('Post Category', 'schema-premium'),
			//'post_taxonomy' 	=> __('Post Taxonomy', 'schema-premium'),
			'post' 				=> __('Specific Post', 'schema-premium'), 
		),
		'Page' => array ( 
			//'page_template' 	=> __('Page Template', 'schema-premium'), 
			//'page_type' 		=> __('Page Type', 'schema-premium'),
			//'page_parent' 		=> __('Page Parent', 'schema-premium'), 
			'page' 				=> __('Specific Page', 'schema-premium'), 
		),
		'Specific ID' => array ( 
			'post_id' 			=> __('Post id', 'schema-premium'),
		)					
	);
											
	return apply_filters( 'schema_wp_get_locations_choices', $options );
}

/**
 * Get Sub Repeater Fields array
 *
 * To set conditional logic based on selection
 *
 * @since 1.0.0
 *
 * @return array
 */
function schema_wp_get_locations_fields_options() {
		
	$feilds = array(
		'schema_post_type' => array(
			'type' => 'post_type_select',
			'value' => 'post_type',
		),
		'schema_post_formats' => array(
			'type' => 'post_formats_select',
			'value' => 'post_format',
		),
		'schema_post_statuses_select' => array(
			'type' => 'post_statuses_select',
			'value' => 'post_status',
		),
		'schema_categories_select' => array(
			'type' => 'schema_categories_select',
			'value' => 'post_category',
		),
		'schema_post_id' => array(
			'type' => 'text',
			'value' => 'post_id',
		),
	);
	
	return apply_filters( 'schema_wp_get_locations_fields_options', $feilds );
}


add_action( 'admin_head', 'schema_wp_custom_acf_repeater_ovderride' );
/**
 * Repeater styles override for Schema post type screen
 *
 * @since 1.0.0
 *
 * @return void
 */
function schema_wp_custom_acf_repeater_ovderride() {
	
	$screen = get_current_screen();
    
	if ( ! isset($screen->post_type) )
		return;
	
	/*
     * Check if current screen is Schema post type
     * Don't output script if it's not
     */
    if ( $screen->post_type != 'schema' )
        return;
		
	echo '<style type="text/css">
   			.acf-repeater > table,
        	.acf-table > thead > tr > th,
			.acf-table > tbody > tr > td {
				border:0;
				padding:0;
			}
			.acf-repeater .acf-row-handle.order {
				cursor: default;
				position: absolute;
    			left: -1999px;
			}
			.acf-table > tbody,
			.acf-repeater .acf-row-handle.remove {
				background: #fff !important;
			}
			.acf-fields.-border,
			.acf-field[data-width] + .acf-field[data-width] {
				border: 0;
			}
			.acf-fields > .acf-field {
				padding: 3px 6px;
			}
			.acf-repeater .acf-actions {
				text-align: right;
				margin-right: 22px;
			}
			.acf-table > thead > tr > th  {
				padding-bottom: 8px;
			}
			.acf-actions .button-primary {
				color: #555 !important;
    			border-color: #ccc !important;
    			background: #f7f7f7 !important;
    			box-shadow: 0 1px 0 #ccc !important;
				text-shadow: none !important;
			}
         </style>';
}


add_action( 'acf/input/admin_footer', 'schema_wp_disable_drag_drop_repeater' );
/**
 * Disable drag & drop repeater feature if current screen is Schema post type
 *
 * @since 1.0.0
 *
 * @return void
 */
function schema_wp_disable_drag_drop_repeater() {
	
    $screen = get_current_screen();
    /*
     * Check if current screen is Schema post type
     * Don't output script if it's not
     */
    if ( $screen->post_type != 'schema' )
        return;
		
    ?>
    <script type="text/javascript">
        (function($) {
            if (typeof acf !== 'undefined') {
                /*$.extend( acf.fields.repeater, {
                    _mouseenter: function( e ){
                        if( $( this.$tbody.closest('.acf-field-repeater') ).hasClass('disable-sorting') ){
                            return;
                        }
                    }
                });*/
				$('.acf-row-handle a[data-event="add-row"]').remove();
				$('.acf-actions a').removeClass('button-primary')
            }
        })(jQuery);
    </script>
    <?php
}
