<?php
/**
 *  VideoObject Details extention
 *
 *  Adds schema VideoObject 
 *
 *  @since 1.0.9
 */
 
if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly

add_filter('schema_single_item_output', 'schema_premium_video_object_details_markup_output');
//add_filter( 'schema_output', 'schema_premium_video_object_details_markup_output' );
//add_filter( 'schema_output_blog_post', 'schema_premium_video_object_details_markup_output' );
//add_filter( 'schema_output_blog_single_ListItem', 'schema_premium_video_object_details_markup_output' );
/**
 * Output Markup
 *
 * @since 1.0.9
 */
function schema_premium_video_object_details_markup_output( $schema ) {
	
	if ( empty($schema) ) return;
	
	$enabled = schema_wp_get_option( 'video_object_meta_enable' );
	
	if ( $enabled != true )
		return $schema;
	
	$video_object_details = schema_premium_get_video_object_details();
	
	if ( ! empty( $video_object_details ) ) {
		
		if ( empty($schema['video']) ) {
			$schema['video'] = $video_object_details;
		} else {
			// Reconstruct our array
			$old_val = $schema['video'];
			$schema['video'] = array();
			$schema['video'][] = $old_val;
			foreach ($video_object_details as $details) {
				$schema['video'][] = $details;
			}
			
		}
	}
	
	//echo'<pre>'; print_r( $schema ); echo'</pre>'; //exit;
	
	return $schema;
}

/**
 * Get VideoObject details 
 *
 * @since 1.0.9
 *
 * return array
 */
function schema_premium_get_video_object_details() {
	
	$video_object = array();
	
	// check if the repeater field has rows of data
	if( have_rows('field_schema_VideoObject_details_repeater', get_the_ID() ) ):
		
		// loop through the rows of data
    	while ( have_rows('field_schema_VideoObject_details_repeater', get_the_ID() ) ) : the_row();

        	// get sub fields values
			$name 			= get_sub_field('feild_schema_VideoObject_details_name');
			$description 	= get_sub_field('feild_schema_VideoObject_details_description');
			$thumbnailUrl 	= get_sub_field('feild_schema_VideoObject_details_thumbnailUrl');
			$uploadDate 	= get_sub_field('feild_schema_VideoObject_details_uploadDate');
			
			
        	$video_object[] = array
			(
				'@type'			=> 'VideoObject',
				'name' 			=> $name,
				'description' 	=> $description,
				'thumbnailUrl' 	=> $thumbnailUrl['url'],
				'uploadDate' 	=> $uploadDate,
			);

    	endwhile;

	else :

    	// no rows found

	endif;
	
	return $video_object;
}

add_action( 'acf/init', 'schema_premium_acf_meta_video_object_details' );
/**
 * VideoObject Details - ACF Meta Box
 *
 * @since 1.0.9
 */
function schema_premium_acf_meta_video_object_details() {
		
	$enabled = schema_wp_get_option( 'video_object_meta_enable' );
	
	if ( $enabled != true )
		return;
		
	if( function_exists('acf_add_local_field_group') ):
		
		// Get setting for display instructions
		$properties_instructions_enable = schema_wp_get_option( 'properties_instructions_enable' );
		
		// ACF Field: Video Details
		// 
		//
		acf_add_local_field_group(array (
			'key' => 'group_schema_VideoObject_details',
			'title' => __('Video Details', 'schema-premium'),
			'location' => array (
				array (
					array (	 // custom location
						'param' => 'is_schema',
						'operator' => '==',
						'value' => 'true',
					),
					array ( // Exclude from schema post type
						'param' => 'post_type',
						'operator' => '!=',
						'value' => 'schema',
					),
				),
			),
			'menu_order' => 0,
			'position' => 'normal',
			'style' => 'default',
			'label_placement' => 'top',
			'instruction_placement' => 'label',
			'hide_on_screen' => '',
			'active' => 1,
			'description' => '',
		));
		
		// Repeater
		// 
		// Video details repeater
		acf_add_local_field( array(
			'key'          => 'field_schema_VideoObject_details_repeater',
			'label'        => '',
			'name'         => 'schema_VideoObject_details_repeater',
			'type'         => 'repeater',
			'parent'       => 'group_schema_VideoObject_details',
			'instructions' => $properties_instructions_enable == 'yes' ? __('Mark up your video content manually with structured data to make Google Search an entry point for discovering and watching videos. Use this feature if your videos are not supported by Schema Premium plugin.', 'schema-wp-types') : '',
			'layout' 	   => 'block',
			'button_label' => __('Add Video Details', 'schema-wp-types'),
		) );
		
		// Sub Repeater
		// 
		// Video details: Name
		acf_add_local_field(array(
			'key' 		=> 'feild_schema_VideoObject_details_name',
			'label' 	=> 'Name',
			'name' 		=> 'schema_VideoObject_details_name',
			'type' 		=> 'text',
			'parent' 	=> 'field_schema_VideoObject_details_repeater',
			'default_value' => '',
			'placeholder' => '',
		));
		
		// Sub Repeater
		// 
		// Video details: Description
		acf_add_local_field(array(
			'key' 		=> 'feild_schema_VideoObject_details_description',
			'label' 	=> 'Description',
			'name' 		=> 'schema_VideoObject_details_description',
			'type' 		=> 'textarea',
			'parent' 	=> 'field_schema_VideoObject_details_repeater',
			'rows' 		=> '3',
			'default_value' => '',
			'placeholder' => '',
		));
		
		// Sub Repeater
		// 
		// Video details: thumbnailUrl
		acf_add_local_field(array(
			'key' 		=> 'feild_schema_VideoObject_details_thumbnailUrl',
			'label' 	=> 'Thumbnail',
			'name' 		=> 'schema_VideoObject_details_thumbnailUrl',
			'type' 		=> 'image',
			'parent' 	=> 'field_schema_VideoObject_details_repeater',
			'default_value' => ''
		));
		
		// Sub Repeater
		// 
		// Video details: uploadDate
		acf_add_local_field(array(
			'key' 		=> 'feild_schema_VideoObject_details_uploadDate',
			'label' 	=> 'Upload Date',
			'name' 		=> 'schema_VideoObject_details_uploadDate',
			'type' 		=> 'date_time_picker',
			'parent' 	=> 'field_schema_VideoObject_details_repeater',
			'return_format' => 'Y-m-d H:i:s',
			'default_value' => '',
		));
		
	endif;
}
