<?php
/**
 * Schema Premium Install
 *
 * @since 1.0.0
 */
 
// Exit if accessed directly
if ( ! defined( 'ABSPATH' ) ) exit;

function schema_wp_install() {

	// Create caps
	$roles = new Schema_WP_Capabilities;
	$roles->add_roles();
	$roles->add_caps();

	$older_plugin_version = get_option( 'schema_premium_version' );
	
	// Add Upgraded From Option
	if ( $older_plugin_version ) {
		update_option( 'schema_premium_version_upgraded_from', $older_plugin_version );
	}
	
	// Check if Schema Premium is already installed, or was installed before
	if ( ! get_option( 'schema_premium_is_installed' )  ) {
		
		// Get saved settings
		$options = schema_wp_get_settings();
		
		// If no saved settings
		if ( empty($options) ) {
			// Set defaults
			$default_options = array(
				//'blog_markup' 				=> 'blog',
				'schema_output_location' 	=> 'head',
				'json_ld_output_format' 	=> 'minified',
				'schema_test_link' 			=> 'yes',
				'properties_instructions' 	=> 'yes',
				
				'breadcrumbs_home_text'		=> 'Blog',		
			);
			
			// Save defaults
			update_option( 'schema_wp_settings', $default_options );
		}
	}

	// Update plugin version
	update_option( 'schema_premium_is_installed', '1' );
	update_option( 'schema_premium_version', SCHEMAPREMIUM_VERSION );
	
	// Bail if activating from network, or bulk
	if ( is_network_admin() || isset( $_GET['activate-multi'] ) ) {
		return;
	}
}
register_activation_hook( SCHEMAPREMIUM_PLUGIN_FILE, 'schema_wp_install' );


function schema_wp_check_if_installed() {

	// this is mainly for network activated installs
	if(  ! get_option( 'schema_premium_is_installed' ) ) {
		schema_wp_install();
	}
}
add_action( 'admin_init', 'schema_wp_check_if_installed' );


/**
 * Install user roles on sub-sites of a network
 *
 * Roles do not get created when Schema is network activation so we need to create them during admin_init
 *
 * @since 1.0.0
 * @return void
 */
function schema_wp_install_roles_on_network() {

	global $wp_roles;

	if( ! is_object( $wp_roles ) ) {
		return;
	}

	if( ! in_array( 'manage_schema', $wp_roles->roles ) ) {

		// Create EDD shop roles
		$roles = new Schema_WP_Capabilities;
		$roles->add_roles();
		$roles->add_caps();
	}

}
add_action( 'admin_init', 'schema_wp_install_roles_on_network' );
